_`umbra.components.factory.componentsManagerUi.nodes`
=====================================================

.. automodule:: umbra.components.factory.componentsManagerUi.nodes

Module Attributes
-----------------

.. attribute:: umbra.components.factory.componentsManagerUi.nodes.LOGGER

Classes
-------

.. autoclass:: PathNode
	:show-inheritance:
	:members:

.. autoclass:: ComponentNode
	:show-inheritance:
	:members:

